pokemon = [
    'abomasnow-mega',
    'abomasnow',
    'abra',
    'absol-mega',
    'absol',
    'accelgor',
    'aegislash-blade',
    'aegislash',
    'aerodactyl-mega',
    'aerodactyl',
    'aggron-mega',
    'aggron',
    'aipom',
    'alakazam-mega',
    'alakazam',
    'alcremie-gmax',
    'alcremie',
    'alomomola',
    'altaria-mega',
    'altaria',
    'amaura',
    'ambipom',
    'amoonguss',
    'ampharos-mega',
    'ampharos',
    'annihilape',
    'anorith',
    'appletun-gmax',
    'appletun',
    'applin',
    'araquanid',
    'arbok',
    'arboliva',
    'arcanine-hisui',
    'arcanine',
    'arceus',
    'archaludon',
    'archen',
    'archeops',
    'arctibax',
    'arctovish',
    'arctozolt',
    'ariados',
    'armaldo',
    'armarouge',
    'aromatisse',
    'aron',
    'arrokuda',
    'articuno-galar',
    'articuno',
    'audino-mega',
    'audino',
    'aurorus',
    'avalugg-hisui',
    'avalugg',
    'axew',
    'azelf',
    'azumarill',
    'azurill',
    'bagon',
    'baltoy',
    'banette-mega',
    'banette',
    'barbaracle',
    'barboach',
    'barraskewda',
    'basculegion',
    'basculin',
    'bastiodon',
    'baxcalibur',
    'bayleef',
    'beartic',
    'beautifly',
    'beedrill-mega',
    'beedrill',
    'beheeyem',
    'beldum',
    'bellibolt',
    'bellossom',
    'bellsprout',
    'bergmite',
    'bewear',
    'bibarel',
    'bidoof',
    'binacle',
    'bisharp',
    'blacephalon',
    'blastoise-gmax',
    'blastoise-mega',
    'blastoise',
    'blaziken-mega',
    'blaziken',
    'blipbug',
    'blissey',
    'blitzle',
    'boldore',
    'boltund',
    'bombirdier',
    'bonsly',
    'bouffalant',
    'bounsweet',
    'braixen',
    'brambleghast',
    'bramblin',
    'braviary-hisui',
    'braviary',
    'breloom',
    'brionne',
    'bronzong',
    'bronzor',
    'brute-bonnet',
    'bruxish',
    'budew',
    'buizel',
    'bulbasaur',
    'buneary',
    'bunnelby',
    'burmy',
    'butterfree-gmax',
    'butterfree',
    'buzzwole',
    'cacnea',
    'cacturne',
    'calyrex-ice-rider',
    'calyrex',
    'calyrex-shadow-rider',
    'camerupt-mega',
    'camerupt',
    'capsakid',
    'carbink',
    'carkol',
    'carnivine',
    'carracosta',
    'carvanha',
    'cascoon',
    'castform',
    'castform-rainy',
    'castform-snowy',
    'castform-sunny',
    'caterpie',
    'celebi',
    'celesteela',
    'centiskorch-gmax',
    'centiskorch',
    'ceruledge',
    'cetitan',
    'cetoddle',
    'chandelure',
    'chansey',
    'charcadet',
    'charizard-gmax',
    'charizard-mega-x',
    'charizard-mega-y',
    'charizard',
    'charjabug',
    'charmander',
    'charmeleon',
    'chatot',
    'cherrim',
    'cherrim-sunshine',
    'cherubi',
    'chesnaught',
    'chespin',
    'chewtle',
    'chien-pao',
    'chikorita',
    'chimchar',
    'chimecho',
    'chinchou',
    'chingling',
    'chi-yu',
    'cinccino',
    'cinderace-gmax',
    'cinderace',
    'clamperl',
    'clauncher',
    'clawitzer',
    'claydol',
    'clefable',
    'clefairy',
    'cleffa',
    'clobbopus',
    'clodsire',
    'cloyster',
    'coalossal-gmax',
    'coalossal',
    'cobalion',
    'cofagrigus',
    'combee',
    'combusken',
    'comfey',
    'conkeldurr',
    'copperajah-gmax',
    'copperajah',
    'corphish',
    'corsola-galar',
    'corsola',
    'corviknight-gmax',
    'corviknight',
    'corvisquire',
    'cosmoem',
    'cosmog',
    'cottonee',
    'crabominable',
    'crabrawler',
    'cradily',
    'cramorant',
    'cranidos',
    'crawdaunt',
    'cresselia',
    'croagunk',
    'crobat',
    'crocalor',
    'croconaw',
    'crustle',
    'cryogonal',
    'cubchoo',
    'cubone',
    'cufant',
    'cursola',
    'cutiefly',
    'cyclizar',
    'cyndaquil',
    'dachsbun',
    'darkrai',
    'darmanitan-galar',
    'darmanitan-galar-zen',
    'darmanitan',
    'darmanitan-zen',
    'dartrix',
    'darumaka-galar',
    'darumaka',
    'decidueye-hisui',
    'decidueye',
    'dedenne',
    'deerling',
    'deino',
    'delcatty',
    'delibird',
    'delphox',
    'deoxys-attack',
    'deoxys-defense',
    'deoxys',
    'deoxys-speed',
    'dewgong',
    'dewott',
    'dewpider',
    'dhelmise',
    'dialga-origin',
    'dialga',
    'diancie-mega',
    'diancie',
    'diggersby',
    'diglett-alola',
    'diglett',
    'dipplin',
    'ditto',
    'dodrio',
    'doduo',
    'dolliv',
    'dondozo',
    'donphan',
    'dottler',
    'doublade',
    'dracovish',
    'dracozolt',
    'dragalge',
    'dragapult',
    'dragonair',
    'dragonite',
    'drakloak',
    'drampa',
    'drapion',
    'dratini',
    'drednaw-gmax',
    'drednaw',
    'dreepy',
    'drifblim',
    'drifloon',
    'drilbur',
    'drizzile',
    'drowzee',
    'druddigon',
    'dubwool',
    'ducklett',
    'dudunsparce',
    'dugtrio-alola',
    'dugtrio',
    'dunsparce',
    'duosion',
    'duraludon-gmax',
    'duraludon',
    'durant',
    'dusclops',
    'dusknoir',
    'duskull',
    'dustox',
    'dwebble',
    'eelektrik',
    'eelektross',
    'eevee-gmax',
    'eevee',
    'eiscue-noice',
    'eiscue',
    'ekans',
    'eldegoss',
    'electabuzz',
    'electivire',
    'electrike',
    'electrode-hisui',
    'electrode',
    'elekid',
    'elgyem',
    'emboar',
    'emolga',
    'empoleon',
    'enamorus',
    'enamorus-therian',
    'entei',
    'escavalier',
    'espathra',
    'espeon',
    'espurr',
    'eternatus-eternamax',
    'eternatus',
    'excadrill',
    'exeggcute',
    'exeggutor-alola',
    'exeggutor',
    'exploud',
    'falinks',
    'farfetchd-galar',
    'farfetchd',
    'farigiraf',
    'fearow',
    'feebas',
    'fennekin',
    'feraligatr',
    'ferroseed',
    'ferrothorn',
    'fezandipiti',
    'fidough',
    'finizen',
    'finneon',
    'flaaffy',
    'flabebe',
    'flamigo',
    'flapple-gmax',
    'flapple',
    'flareon',
    'fletchinder',
    'fletchling',
    'flittle',
    'floatzel',
    'floette',
    'floragato',
    'florges',
    'flutter-mane',
    'flygon',
    'fomantis',
    'foongus',
    'forretress',
    'fraxure',
    'frigibax',
    'frillish',
    'froakie',
    'frogadier',
    'froslass',
    'frosmoth',
    'fuecoco',
    'furfrou',
    'furret',
    'gabite',
    'gallade-mega',
    'gallade',
    'galvantula',
    'garbodor-gmax',
    'garbodor',
    'garchomp-mega',
    'garchomp',
    'gardevoir-mega',
    'gardevoir',
    'garganacl',
    'gastly',
    'gastrodon',
    'genesect',
    'gengar-gmax',
    'gengar-mega',
    'gengar',
    'geodude-alola',
    'geodude',
    'gholdengo',
    'gible',
    'gigalith',
    'gimmighoul',
    'girafarig',
    'giratina-origin',
    'giratina',
    'glaceon',
    'glalie-mega',
    'glalie',
    'glameow',
    'glastrier',
    'gligar',
    'glimmet',
    'glimmora',
    'gliscor',
    'gloom',
    'gogoat',
    'golbat',
    'goldeen',
    'golduck',
    'golem-alola',
    'golem',
    'golett',
    'golisopod',
    'golurk',
    'goodra-hisui',
    'goodra',
    'goomy',
    'gorebyss',
    'gossifleur',
    'gothita',
    'gothitelle',
    'gothorita',
    'gouging-fire',
    'gourgeist',
    'grafaiai',
    'granbull',
    'grapploct',
    'graveler-alola',
    'graveler',
    'great-tusk',
    'greavard',
    'greedent',
    'greninja-ash',
    'greninja',
    'grimer-alola',
    'grimer',
    'grimmsnarl-gmax',
    'grimmsnarl',
    'grookey',
    'grotle',
    'groudon',
    'groudon-primal',
    'grovyle',
    'growlithe-hisui',
    'growlithe',
    'grubbin',
    'grumpig',
    'gulpin',
    'gumshoos',
    'gurdurr',
    'guzzlord',
    'gyarados-mega',
    'gyarados',
    'hakamo-o',
    'happiny',
    'hariyama',
    'hatenna',
    'hatterene-gmax',
    'hatterene',
    'hattrem',
    'haunter',
    'hawlucha',
    'haxorus',
    'heatmor',
    'heatran',
    'heliolisk',
    'helioptile',
    'heracross-mega',
    'heracross',
    'herdier',
    'hippopotas',
    'hippowdon',
    'hitmonchan',
    'hitmonlee',
    'hitmontop',
    'honchkrow',
    'honedge',
    'ho-oh',
    'hoopa',
    'hoopa-unbound',
    'hoothoot',
    'hoppip',
    'horsea',
    'houndoom-mega',
    'houndoom',
    'houndour',
    'houndstone',
    'huntail',
    'hydrapple',
    'hydreigon',
    'hypno',
    'igglybuff',
    'illumise',
    'impidimp',
    'incineroar',
    'indeedee',
    'infernape',
    'inkay',
    'inteleon-gmax',
    'inteleon',
    'iron-boulder',
    'iron-bundle',
    'iron-crown',
    'iron-hands',
    'iron-jugulis',
    'iron-leaves',
    'iron-moth',
    'iron-thorns',
    'iron-treads',
    'iron-valiant',
    'ivysaur',
    'jangmo-o',
    'jellicent',
    'jigglypuff',
    'jirachi',
    'jolteon',
    'joltik',
    'jumpluff',
    'jynx',
    'kabuto',
    'kabutops',
    'kadabra',
    'kakuna',
    'kangaskhan-mega',
    'kangaskhan',
    'karrablast',
    'kartana',
    'kecleon',
    'keldeo',
    'keldeo-resolute',
    'kilowattrel',
    'kingambit',
    'kingdra',
    'kingler-gmax',
    'kingler',
    'kirlia',
    'klang',
    'klawf',
    'kleavor',
    'klefki',
    'klinklang',
    'klink',
    'koffing',
    'komala',
    'kommo-o',
    'koraidon',
    'krabby',
    'kricketot',
    'kricketune',
    'krokorok',
    'krookodile',
    'kubfu',
    'kyogre',
    'kyogre-primal',
    'kyurem-black',
    'kyurem',
    'kyurem-white',
    'lairon',
    'lampent',
    'landorus',
    'landorus-therian',
    'lanturn',
    'lapras-gmax',
    'lapras',
    'larvesta',
    'larvitar',
    'latias-mega',
    'latias',
    'latios-mega',
    'latios',
    'leafeon',
    'leavanny',
    'lechonk',
    'ledian',
    'ledyba',
    'lickilicky',
    'lickitung',
    'liepard',
    'lileep',
    'lilligant-hisui',
    'lilligant',
    'lillipup',
    'linoone-galar',
    'linoone',
    'litleo',
    'litten',
    'litwick',
    'lokix',
    'lombre',
    'lopunny-mega',
    'lopunny',
    'lotad',
    'loudred',
    'lucario-mega',
    'lucario',
    'ludicolo',
    'lugia',
    'lumineon',
    'lunala',
    'lunatone',
    'lurantis',
    'luvdisc',
    'luxio',
    'luxray',
    'lycanroc-dusk',
    'lycanroc-midnight',
    'lycanroc',
    'mabosstiff',
    'machamp-gmax',
    'machamp',
    'machoke',
    'machop',
    'magby',
    'magcargo',
    'magearna',
    'magikarp',
    'magmar',
    'magmortar',
    'magnemite',
    'magneton',
    'magnezone',
    'makuhita',
    'malamar',
    'mamoswine',
    'manaphy',
    'mandibuzz',
    'manectric-mega',
    'manectric',
    'mankey',
    'mantine',
    'mantyke',
    'maractus',
    'mareanie',
    'mareep',
    'marill',
    'marowak-alola',
    'marowak',
    'marshadow',
    'marshtomp',
    'maschiff',
    'masquerain',
    'maushold',
    'mawile-mega',
    'mawile',
    'medicham-mega',
    'medicham',
    'meditite',
    'meganium',
    'melmetal-gmax',
    'melmetal',
    'meloetta-pirouette',
    'meloetta',
    'meltan',
    'meowscarada',
    'meowstic',
    'meowth-alola',
    'meowth-galar',
    'meowth-gmax',
    'meowth',
    'mesprit',
    'metagross-mega',
    'metagross',
    'metang',
    'metapod',
    'mew',
    'mewtwo-mega-x',
    'mewtwo-mega-y',
    'mewtwo',
    'mienfoo',
    'mienshao',
    'mightyena',
    'milcery',
    'milotic',
    'miltank',
    'mime-jr',
    'mimikyu',
    'minccino',
    'minior',
    'minun',
    'miraidon',
    'misdreavus',
    'mismagius',
    'moltres-galar',
    'moltres',
    'monferno',
    'morelull',
    'morgrem',
    'morpeko-hangry',
    'morpeko',
    'mothim',
    'mr-mime-galar',
    'mr-mime',
    'mr-rime',
    'mudbray',
    'mudkip',
    'mudsdale',
    'muk-alola',
    'muk',
    'munchlax',
    'munkidori',
    'munna',
    'murkrow',
    'musharna',
    'nacli',
    'naclstack',
    'naganadel',
    'natu',
    'necrozma',
    'necrozma-ultra',
    'nickit',
    'nidoking',
    'nidoqueen',
    'nidoran-f',
    'nidoran-m',
    'nidorina',
    'nidorino',
    'nihilego',
    'nincada',
    'ninetales-alola',
    'ninetales',
    'ninjask',
    'noctowl',
    'noibat',
    'noivern',
    'nosepass',
    'numel',
    'nuzleaf',
    'nymble',
    'obstagoon',
    'octillery',
    'oddish',
    'ogerpon-teal-mask',
    'ogerpon-wellspring-mask',
    'ogerpon-hearthflame-mask',
    'ogerpon-cornerstone-mask',
    'oinkologne',
    'okidogi',
    'omanyte',
    'omastar',
    'onix',
    'oranguru',
    'orbeetle-gmax',
    'orbeetle',
    'oricorio-pau',
    'oricorio',
    'oricorio-pom-pom',
    'oricorio-sensu',
    'orthworm',
    'oshawott',
    'overqwil',
    'pachirisu',
    'palafin',
    'palkia-origin',
    'palkia',
    'palossand',
    'palpitoad',
    'pancham',
    'pangoro',
    'panpour',
    'pansage',
    'pansear',
    'parasect',
    'paras',
    'passimian',
    'patrat',
    'pawmi',
    'pawmo',
    'pawmot',
    'pawniard',
    'pecharunt',
    'pelipper',
    'perrserker',
    'persian-alola',
    'persian',
    'petilil',
    'phanpy',
    'phantump',
    'pheromosa',
    'phione',
    'pichu',
    'pidgeot-mega',
    'pidgeot',
    'pidgeotto',
    'pidgey',
    'pidove',
    'pignite',
    'pikachu-gmax',
    'pikachu',
    'pikipek',
    'piloswine',
    'pincurchin',
    'pineco',
    'pinsir-mega',
    'pinsir',
    'piplup',
    'plusle',
    'poipole',
    'politoed',
    'poliwag',
    'poliwhirl',
    'poliwrath',
    'poltchageist',
    'polteageist',
    'ponyta-galar',
    'ponyta',
    'poochyena',
    'popplio',
    'porygon2',
    'porygon',
    'porygon-z',
    'primarina',
    'primeape',
    'prinplup',
    'probopass',
    'psyduck',
    'pumpkaboo',
    'pupitar',
    'purrloin',
    'purugly',
    'pyroar',
    'pyukumuku',
    'quagsire',
    'quaquaval',
    'quaxly',
    'quaxwell',
    'quilava',
    'quilladin',
    'qwilfish-hisui',
    'qwilfish',
    'raboot',
    'rabsca',
    'raging-bolt',
    'raichu-alola',
    'raichu',
    'raikou',
    'ralts',
    'rampardos',
    'rapidash-galar',
    'rapidash',
    'raticate-alola',
    'raticate',
    'rattata-alola',
    'rattata',
    'rayquaza-mega',
    'rayquaza',
    'regice',
    'regidrago',
    'regieleki',
    'regigigas',
    'regirock',
    'registeel',
    'relicanth',
    'rellor',
    'remoraid',
    'reshiram',
    'reuniclus',
    'revavroom',
    'rhydon',
    'rhyhorn',
    'rhyperior',
    'ribombee',
    'rillaboom-gmax',
    'rillaboom',
    'riolu',
    'roaring-moon',
    'rockruff',
    'roggenrola',
    'rolycoly',
    'rookidee',
    'roselia',
    'roserade',
    'rotom-fan',
    'rotom-frost',
    'rotom-heat',
    'rotom-mow',
    'rotom',
    'rotom-wash',
    'rowlet',
    'rufflet',
    'runerigus',
    'sableye-mega',
    'sableye',
    'salamence-mega',
    'salamence',
    'salandit',
    'salazzle',
    'samurott-hisui',
    'samurott',
    'sandaconda-gmax',
    'sandaconda',
    'sandile',
    'sandshrew-alola',
    'sandshrew',
    'sandslash-alola',
    'sandslash',
    'sandygast',
    'sandy-shocks',
    'sawk',
    'sawsbuck',
    'scatterbug',
    'sceptile-mega',
    'sceptile',
    'scizor-mega',
    'scizor',
    'scolipede',
    'scorbunny',
    'scovillain',
    'scrafty',
    'scraggy',
    'scream-tail',
    'scyther',
    'seadra',
    'seaking',
    'sealeo',
    'seedot',
    'seel',
    'seismitoad',
    'sentret',
    'serperior',
    'servine',
    'seviper',
    'sewaddle',
    'sharpedo-mega',
    'sharpedo',
    'shaymin',
    'shaymin-sky',
    'shedinja',
    'shelgon',
    'shellder',
    'shellos',
    'shelmet',
    'shieldon',
    'shiftry',
    'shiinotic',
    'shinx',
    'shroodle',
    'shroomish',
    'shuckle',
    'shuppet',
    'sigilyph',
    'silcoon',
    'silicobra',
    'silvally',
    'simipour',
    'simisage',
    'simisear',
    'sinistcha',
    'sinistea',
    'sirfetchd',
    'sizzlipede',
    'skarmory',
    'skeledirge',
    'skiddo',
    'skiploom',
    'skitty',
    'skorupi',
    'skrelp',
    'skuntank',
    'skwovet',
    'slaking',
    'slakoth',
    'sliggoo-hisui',
    'sliggoo',
    'slither-wing',
    'slowbro-galar',
    'slowbro-mega',
    'slowbro',
    'slowking-galar',
    'slowking',
    'slowpoke-galar',
    'slowpoke',
    'slugma',
    'slurpuff',
    'smeargle',
    'smoliv',
    'smoochum',
    'sneasel-hisui',
    'sneasel',
    'sneasler',
    'snivy',
    'snom',
    'snorlax-gmax',
    'snorlax',
    'snorunt',
    'snover',
    'snubbull',
    'sobble',
    'solgaleo',
    'solosis',
    'solrock',
    'spearow',
    'spectrier',
    'spewpa',
    'spheal',
    'spidops',
    'spinarak',
    'spinda',
    'spiritomb',
    'spoink',
    'sprigatito',
    'spritzee',
    'squawkabilly-green',
    'squirtle',
    'stakataka',
    'stantler',
    'staraptor',
    'staravia',
    'starly',
    'starmie',
    'staryu',
    'steelix-mega',
    'steelix',
    'steenee',
    'stonjourner',
    'stoutland',
    'stufful',
    'stunfisk-galar',
    'stunfisk',
    'stunky',
    'sudowoodo',
    'suicune',
    'sunflora',
    'sunkern',
    'surskit',
    'swablu',
    'swadloon',
    'swalot',
    'swampert-mega',
    'swampert',
    'swanna',
    'swellow',
    'swinub',
    'swirlix',
    'swoobat',
    'sylveon',
    'tadbulb',
    'taillow',
    'talonflame',
    'tandemaus',
    'tangela',
    'tangrowth',
    'tapu-bulu',
    'tapu-fini',
    'tapu-koko',
    'tapu-lele',
    'tarountula',
    'tatsugiri-droopy',
    'tatsugiri',
    'tatsugiri-stretchy',
    'tauros',
    'teddiursa',
    'tentacool',
    'tentacruel',
    'tepig',
    'terapagos-terastal',
    'terrakion',
    'thievul',
    'throh',
    'thundurus',
    'thundurus-therian',
    'thwackey',
    'timburr',
    'ting-lu',
    'tinkatink',
    'tinkaton',
    'tinkatuff',
    'tirtouga',
    'toedscool',
    'toedscruel',
    'togedemaru',
    'togekiss',
    'togepi',
    'togetic',
    'torchic',
    'torkoal',
    'tornadus',
    'tornadus-therian',
    'torracat',
    'torterra',
    'totodile',
    'toucannon',
    'toxapex',
    'toxel',
    'toxicroak',
    'toxtricity-gmax',
    'toxtricity-low-key',
    'toxtricity',
    'tranquill',
    'trapinch',
    'treecko',
    'trevenant',
    'tropius',
    'trubbish',
    'trumbeak',
    'tsareena',
    'turtonator',
    'turtwig',
    'tympole',
    'tynamo',
    'type-null',
    'typhlosion-hisui',
    'typhlosion',
    'tyranitar-mega',
    'tyranitar',
    'tyrantrum',
    'tyrogue',
    'tyrunt',
    'umbreon',
    'unfezant',
    'unown',
    'ursaluna',
    'ursaluna-bloodmoon',
    'ursaring',
    'urshifu-gmax',
    'urshifu',
    'urshifu-rapid-strike-gmax',
    'uxie',
    'vanillish',
    'vanillite',
    'vanilluxe',
    'vaporeon',
    'varoom',
    'veluza',
    'venipede',
    'venomoth',
    'venonat',
    'venusaur-gmax',
    'venusaur-mega',
    'venusaur',
    'vespiquen',
    'vibrava',
    'victini',
    'victreebel',
    'vigoroth',
    'vikavolt',
    'vileplume',
    'virizion',
    'vivillon',
    'volbeat',
    'volcanion',
    'volcarona',
    'voltorb-hisui',
    'voltorb',
    'vullaby',
    'vulpix-alola',
    'vulpix',
    'wailmer',
    'wailord',
    'walking-wake',
    'walrein',
    'wartortle',
    'watchog',
    'wattrel',
    'weavile',
    'weedle',
    'weepinbell',
    'weezing-galar',
    'weezing',
    'whimsicott',
    'whirlipede',
    'whiscash',
    'whismur',
    'wigglytuff',
    'wiglett',
    'wimpod',
    'wingull',
    'wishiwashi',
    'wishiwashi-school',
    'wobbuffet',
    'wo-chien',
    'woobat',
    'wooloo',
    'wooper-paldea',
    'wooper',
    'wormadam',
    'wormadam-sandy',
    'wormadam-trash',
    'wugtrio',
    'wurmple',
    'wynaut',
    'wyrdeer',
    'xatu',
    'xerneas-active',
    'xerneas',
    'xurkitree',
    'yamask-galar',
    'yamask',
    'yamper',
    'yanma',
    'yanmega',
    'yungoos',
    'yveltal',
    'zacian-crowned',
    'zacian',
    'zamazenta-crowned',
    'zamazenta',
    'zangoose',
    'zapdos-galar',
    'zapdos',
    'zarude',
    'zebstrika',
    'zekrom',
    'zeraora',
    'zigzagoon-galar',
    'zigzagoon',
    'zoroark-hisui',
    'zoroark',
    'zorua-hisui',
    'zorua',
    'zubat',
    'zweilous',
    'zygarde-10',
    'zygarde-complete',
    'zygarde',
]

pokemon_as_decks = [{
    'name': p.replace('-', ' ').title(),
    'id': p,
    'icons': [p],
} for p in pokemon]
