'''
This file was automatically generated by
`th-scripting/palette_extractor.py`.
'''
ICON_COLOR_MAPPING = {
	"abomasnow-mega": "#4F6057",
	"abomasnow": "#F7F6F6",
	"abra": "#EED845",
	"absol-mega": "#F3F3F3",
	"absol": "#575C6A",
	"accelgor": "#575057",
	"aegislash-blade": "#60594F",
	"aegislash": "#5C554A",
	"aerodactyl-mega": "#3E3A3E",
	"aerodactyl": "#83787B",
	"aggron-mega": "#505050",
	"aggron": "#4E4F4F",
	"aipom": "#B097B7",
	"alakazam-mega": "#746459",
	"alakazam": "#7C6A4E",
	"alcremie-caramel-swirl-berry": "#E9D2B1",
	"alcremie-caramel-swirl-clover": "#CCAD7F",
	"alcremie-caramel-swirl-flower": "#A76D44",
	"alcremie-caramel-swirl-love": "#DBA485",
	"alcremie-caramel-swirl-plain": "#EDD4B1",
	"alcremie-caramel-swirl-ribbon": "#BB9485",
	"alcremie-caramel-swirl-star": "#9E7C54",
	"alcremie-caramel-swirl-strawberry": "#C18D6C",
	"alcremie-gmax": "#EFE9E0",
	"alcremie-lemon-cream-berry": "#F3EEAF",
	"alcremie-lemon-cream-clover": "#CABF5E",
	"alcremie-lemon-cream-flower": "#DEC863",
	"alcremie-lemon-cream-love": "#DCAF69",
	"alcremie-lemon-cream-plain": "#F6F0AF",
	"alcremie-lemon-cream-ribbon": "#F4ECB7",
	"alcremie-lemon-cream-star": "#DBCA48",
	"alcremie-lemon-cream-strawberry": "#DAC565",
	"alcremie-matcha-cream-berry": "#CFE497",
	"alcremie-matcha-cream-clover": "#97AE63",
	"alcremie-matcha-cream-flower": "#CDE08F",
	"alcremie-matcha-cream-love": "#BAA873",
	"alcremie-matcha-cream-plain": "#D6EA9C",
	"alcremie-matcha-cream-ribbon": "#9FA27A",
	"alcremie-matcha-cream-star": "#B5C053",
	"alcremie-matcha-cream-strawberry": "#A3A867",
	"alcremie-mint-cream-berry": "#CBEEF0",
	"alcremie-mint-cream-clover": "#C9EDEF",
	"alcremie-mint-cream-flower": "#C2E7E9",
	"alcremie-mint-cream-love": "#C3E6E9",
	"alcremie-mint-cream-plain": "#CBEEF1",
	"alcremie-mint-cream-ribbon": "#CAECEF",
	"alcremie-mint-cream-star": "#C2E7E8",
	"alcremie-mint-cream-strawberry": "#C9ECEE",
	"alcremie": "#F9E5E0",
	"alcremie-rainbow-swirl-berry": "#EADAB1",
	"alcremie-rainbow-swirl-clover": "#AEA56A",
	"alcremie-rainbow-swirl-flower": "#ECD9AB",
	"alcremie-rainbow-swirl-love": "#D69A6C",
	"alcremie-rainbow-swirl-plain": "#EFE2BB",
	"alcremie-rainbow-swirl-ribbon": "#EDD9B2",
	"alcremie-rainbow-swirl-star": "#EADBB5",
	"alcremie-rainbow-swirl-strawberry": "#BEA370",
	"alcremie-ruby-cream-berry": "#EEB2D2",
	"alcremie-ruby-cream-clover": "#F2B7D5",
	"alcremie-ruby-cream-flower": "#F1B2D0",
	"alcremie-ruby-cream-love": "#F3B7D3",
	"alcremie-ruby-cream-plain": "#F2B9D8",
	"alcremie-ruby-cream-ribbon": "#BF76A0",
	"alcremie-ruby-cream-star": "#F0B3CF",
	"alcremie-ruby-cream-strawberry": "#F2B5D4",
	"alcremie-ruby-swirl-berry": "#F0C0AB",
	"alcremie-ruby-swirl-clover": "#F6CBAF",
	"alcremie-ruby-swirl-flower": "#F4C5A9",
	"alcremie-ruby-swirl-love": "#D87F83",
	"alcremie-ruby-swirl-plain": "#F7D2B1",
	"alcremie-ruby-swirl-ribbon": "#C37F8F",
	"alcremie-ruby-swirl-star": "#F3C2A8",
	"alcremie-ruby-swirl-strawberry": "#F6C9AE",
	"alcremie-salted-cream-berry": "#E4F0E9",
	"alcremie-salted-cream-clover": "#E5F0E9",
	"alcremie-salted-cream-flower": "#E1ECE4",
	"alcremie-salted-cream-love": "#E4ECE6",
	"alcremie-salted-cream-plain": "#E8F2EB",
	"alcremie-salted-cream-ribbon": "#E4EFE9",
	"alcremie-salted-cream-star": "#E1EDE4",
	"alcremie-salted-cream-strawberry": "#E6F1EA",
	"alcremie-vanilla-cream-berry": "#F7E5DF",
	"alcremie-vanilla-cream-clover": "#F8E5DF",
	"alcremie-vanilla-cream-flower": "#F9E7E0",
	"alcremie-vanilla-cream-love": "#F8E3DD",
	"alcremie-vanilla-cream-plain": "#F9E8E2",
	"alcremie-vanilla-cream-ribbon": "#F8E4DF",
	"alcremie-vanilla-cream-star": "#F6E1D9",
	"alcremie-vanilla-cream-strawberry": "#F9E5DF",
	"alomomola": "#F9B7D6",
	"altaria-mega": "#DBE3F3",
	"altaria": "#A2BECA",
	"amaura": "#8AC2EB",
	"ambipom": "#584357",
	"amoonguss": "#CD7E88",
	"ampharos-mega": "#665545",
	"ampharos": "#E8CB41",
	"annihilape": "#BBB9BD",
	"anorith": "#4A4844",
	"appletun-gmax": "#6F4336",
	"appletun": "#E4B268",
	"applin": "#D24E56",
	"araquanid": "#525F62",
	"arbok": "#B293CA",
	"arboliva": "#465825",
	"arcanine-hisui-noble": "#DBC430",
	"arcanine-hisui": "#746969",
	"arcanine": "#CB9E70",
	"arceus-bug": "#606941",
	"arceus-dark": "#565858",
	"arceus-dragon": "#53545B",
	"arceus-electric": "#E6E5E1",
	"arceus-fairy": "#F5ECEF",
	"arceus-fighting": "#211817",
	"arceus-fire": "#EAE9E7",
	"arceus-flying": "#989FB0",
	"arceus-ghost": "#584D5B",
	"arceus-grass": "#536F48",
	"arceus-ground": "#EAE8E7",
	"arceus-ice": "#95AFBA",
	"arceus": "#5D5F4B",
	"arceus-poison": "#624E59",
	"arceus-psychic": "#615353",
	"arceus-rock": "#6D683E",
	"arceus-steel": "#595A58",
	"arceus-unknown": "#4B5956",
	"arceus-water": "#3E5262",
	"archaludon": "#121629",
	"archen": "#AD5F46",
	"archeops": "#207FA1",
	"arctibax": "#748C9F",
	"arctovish": "#ACD0EE",
	"arctozolt": "#5B8390",
	"ariados": "#5F4646",
	"armaldo": "#555558",
	"armarouge": "#1A130F",
	"aromatisse": "#AF72AE",
	"aron": "#C8D0D0",
	"arrokuda": "#9D8873",
	"articuno-galar": "#C4AECC",
	"articuno": "#83C3F0",
	"audino-mega": "#F2EBDB",
	"audino": "#E9A09F",
	"aurorus": "#7396C3",
	"avalugg-hisui-noble": "#D3C937",
	"avalugg-hisui": "#74615B",
	"avalugg": "#E4ECF4",
	"axew": "#51763A",
	"azelf": "#569DC8",
	"azumarill": "#63B7ED",
	"azurill": "#82B3EC",
	"bagon": "#555C68",
	"baltoy": "#B37A58",
	"banette-mega": "#7B7274",
	"banette": "#878179",
	"barbaracle": "#615343",
	"barboach": "#62778F",
	"barraskewda": "#A37D64",
	"basculegion": "#4C7355",
	"basculin-blue-striped": "#5F7E5B",
	"basculin": "#7B875F",
	"basculin-white-striped": "#566B52",
	"bastiodon": "#828078",
	"baxcalibur": "#495568",
	"bayleef": "#E3DE67",
	"beartic": "#E1F2FA",
	"beautifly": "#6A6A6A",
	"beedrill-mega": "#5E5A52",
	"beedrill": "#6D6157",
	"beheeyem": "#988165",
	"beldum": "#6087CF",
	"bellibolt": "#2F916B",
	"bellossom": "#6A8A54",
	"bellsprout": "#EDE457",
	"bergmite": "#A9CDE7",
	"bewear": "#595856",
	"bibarel": "#615243",
	"bidoof": "#BE9661",
	"binacle": "#A67959",
	"bisharp": "#775246",
	"blacephalon": "#F1E0EE",
	"blastoise-gmax": "#545552",
	"blastoise-mega": "#595147",
	"blastoise": "#6E7474",
	"blaziken-mega": "#BE6C4B",
	"blaziken": "#C1734D",
	"blipbug": "#71708D",
	"blissey": "#F3C9D6",
	"blitzle": "#5E605F",
	"boldore": "#434B74",
	"boltund": "#63674D",
	"bombirdier": "#D8D7D7",
	"bonsly": "#719157",
	"bouffalant": "#5E5341",
	"bounsweet": "#C95B89",
	"braixen": "#1E1612",
	"brambleghast": "#6D4E35",
	"bramblin": "#745A40",
	"braviary-hisui": "#31313A",
	"braviary": "#50557B",
	"breloom": "#5C5640",
	"brionne": "#5E9CCE",
	"bronzong": "#5B8181",
	"bronzor": "#538996",
	"brute-bonnet": "#88443F",
	"bruxish": "#BA71B0",
	"budew": "#8AB851",
	"buizel": "#DD8C36",
	"bulbasaur": "#4D7747",
	"buneary": "#B4855D",
	"bunnelby": "#81716A",
	"burmy": "#54604F",
	"burmy-sandy": "#E9DF74",
	"burmy-trash": "#ED928C",
	"butterfree-gmax": "#8CD4B7",
	"butterfree": "#555363",
	"buzzwole": "#63423E",
	"cacnea": "#629252",
	"cacturne": "#4A7048",
	"calyrex-ice-rider": "#365C4F",
	"calyrex": "#335D4B",
	"calyrex-shadow-rider": "#38564D",
	"camerupt-mega": "#C96856",
	"camerupt": "#E17E5C",
	"capsakid": "#759767",
	"carbink": "#7D89A0",
	"carkol": "#534E4A",
	"carnivine": "#6A8549",
	"carracosta": "#484E5C",
	"carvanha": "#C18D47",
	"cascoon": "#DABEEF",
	"castform": "#CDCDCC",
	"castform-rainy": "#78A2F4",
	"castform-snowy": "#446C60",
	"castform-sunny": "#B3613E",
	"caterpie": "#655635",
	"celebi": "#8AB06E",
	"celesteela": "#649D84",
	"centiskorch-gmax": "#724524",
	"centiskorch": "#653B2C",
	"ceruledge": "#1E1F2D",
	"cetitan": "#8C868A",
	"cetoddle": "#E3DBE2",
	"chandelure": "#474649",
	"chansey": "#D78A86",
	"charcadet": "#503D39",
	"charizard-gmax": "#F4A137",
	"charizard-mega-x": "#57606C",
	"charizard-mega-y": "#C76051",
	"charizard": "#C1675C",
	"charjabug": "#91AC67",
	"charmander": "#E37D37",
	"charmeleon": "#DE5E46",
	"chatot": "#464443",
	"cherrim": "#9571CA",
	"cherrim-sunshine": "#E28898",
	"cherubi": "#DB6A8F",
	"chesnaught": "#9A9966",
	"chespin": "#5D5E39",
	"chewtle": "#B6D5CD",
	"chien-pao": "#0A1019",
	"chikorita": "#7CBB56",
	"chimchar": "#D27F48",
	"chimecho": "#CFE1F5",
	"chinchou": "#A5B8DF",
	"chingling": "#1D1610",
	"chi-yu": "#663C2D",
	"cinccino": "#D4DADC",
	"cinderace-gmax": "#F8B12F",
	"cinderace": "#59494D",
	"clamperl": "#484752",
	"clauncher": "#63ADE3",
	"clawitzer": "#5397E1",
	"claydol": "#5E5352",
	"clefable": "#FACCCB",
	"clefairy": "#F8BEA8",
	"cleffa": "#F3B39E",
	"clobbopus": "#E7D6CA",
	"clodsire": "#61514E",
	"cloyster": "#6A6389",
	"coalossal-gmax": "#5F5955",
	"coalossal": "#554D4A",
	"cobalion": "#436768",
	"cofagrigus": "#414344",
	"combee": "#735E3A",
	"combusken": "#F7E784",
	"comfey": "#BCA05A",
	"conkeldurr": "#977669",
	"copperajah-gmax": "#42534F",
	"copperajah": "#2C4443",
	"corphish": "#D06C46",
	"corsola-galar": "#E9E9E8",
	"corsola": "#F29398",
	"corviknight-gmax": "#785A91",
	"corviknight": "#676197",
	"corvisquire": "#474950",
	"cosmoem": "#515155",
	"cosmog": "#4A4963",
	"cottonee": "#E0F2F3",
	"crabominable": "#E3DFDB",
	"crabrawler": "#505460",
	"cradily": "#585D4D",
	"cramorant-gorging": "#325C85",
	"cramorant-gulping": "#315C88",
	"cramorant": "#2F5D8C",
	"cranidos": "#565B62",
	"crawdaunt": "#C74F39",
	"cresselia": "#CE9FC0",
	"croagunk": "#818EDE",
	"crobat": "#6E6F97",
	"crocalor": "#7D3F35",
	"croconaw": "#6AB4D5",
	"crustle": "#745851",
	"cryogonal": "#6B8CCD",
	"cubchoo": "#7EBAEC",
	"cubone": "#ACA08E",
	"cufant": "#E18F63",
	"cursola": "#DED6EB",
	"cutiefly": "#D9C879",
	"cyclizar-mount": "#3E474D",
	"cyclizar": "#3E474D",
	"cyndaquil": "#19120E",
	"dachsbun": "#5E3326",
	"darkrai": "#423F3D",
	"darmanitan-galar": "#FAFBFB",
	"darmanitan-galar-zen": "#E9EBE8",
	"darmanitan": "#B45049",
	"darmanitan-zen": "#496062",
	"dartrix": "#60563E",
	"darumaka-galar": "#EBF2F4",
	"darumaka": "#C04949",
	"decidueye-hisui": "#D17657",
	"decidueye": "#585649",
	"dedenne": "#CE9324",
	"deerling-autumn": "#EBA843",
	"deerling": "#E5BAB2",
	"deerling-summer": "#83AA64",
	"deerling-winter": "#CBAD6A",
	"deino": "#81717E",
	"delcatty": "#AB79BD",
	"delibird": "#E2DFDB",
	"delphox": "#D74323",
	"deoxys-attack": "#544139",
	"deoxys-defense": "#E06F52",
	"deoxys": "#D46A51",
	"deoxys-speed": "#CB664F",
	"dewgong": "#F0F6FC",
	"dewott": "#567490",
	"dewpider": "#709E96",
	"dhelmise": "#4F5143",
	"dialga-origin": "#3D4F5E",
	"dialga": "#455262",
	"diancie-mega": "#A9888B",
	"diancie": "#BC94A3",
	"diggersby": "#7F694E",
	"diglett-alola": "#9B7A5E",
	"diglett": "#695945",
	"dipplin": "#4B3B2C",
	"ditto": "#967CCF",
	"dodrio": "#BA8C5C",
	"doduo": "#D0A976",
	"dolliv": "#478419",
	"dondozo": "#171E2F",
	"donphan": "#5C5F68",
	"dottler": "#E6C653",
	"doublade": "#734A53",
	"dracovish": "#405F5E",
	"dracozolt": "#B66F46",
	"dragalge": "#654338",
	"dragapult": "#596065",
	"dragonair": "#6790C9",
	"dragonite": "#EBB04E",
	"drakloak": "#546367",
	"drampa": "#98B39D",
	"drapion": "#8B6996",
	"dratini": "#819FC8",
	"drednaw-gmax": "#5F6E6C",
	"drednaw": "#655747",
	"dreepy": "#868981",
	"drifblim": "#ACA1D1",
	"drifloon": "#ADA1DB",
	"drilbur": "#877F8E",
	"drizzile": "#527085",
	"drowzee": "#E5CD3F",
	"druddigon": "#1C7BA6",
	"dubwool": "#4F4749",
	"ducklett": "#5A7AA7",
	"dudunsparce": "#DEDAA9",
	"dudunsparce-three-segment": "#DEDCAC",
	"dugtrio-alola": "#5D544C",
	"dugtrio": "#997565",
	"dunsparce": "#F1EBA0",
	"duosion": "#6EB576",
	"duraludon-gmax": "#BADADF",
	"duraludon": "#A6A29E",
	"durant": "#4F4D4B",
	"dusclops": "#817E71",
	"dusknoir": "#626052",
	"duskull": "#908E87",
	"dustox": "#B4A743",
	"dwebble": "#5F4D41",
	"eelektrik": "#4D5CA7",
	"eelektross": "#5B6ABB",
	"eevee-gmax": "#D2AF5E",
	"eevee": "#CCA558",
	"eevee-starter": "#D4A769",
	"eiscue-noice": "#CDE8F2",
	"eiscue": "#CCE2EA",
	"ekans": "#B3759D",
	"eldegoss": "#F9F7EE",
	"electabuzz": "#615755",
	"electivire": "#685E44",
	"electrike": "#82BF6F",
	"electrode-hisui-noble": "#F2E440",
	"electrode-hisui": "#E0C28F",
	"electrode": "#FAF9F9",
	"elekid": "#F2DD3F",
	"elgyem": "#A3E1DE",
	"emboar": "#7D6155",
	"emolga": "#716C66",
	"empoleon": "#31312E",
	"enamorus": "#62464A",
	"enamorus-therian": "#A1565F",
	"entei": "#A46956",
	"escavalier": "#B8AAA0",
	"espathra": "#C4AA8E",
	"espeon": "#535659",
	"espurr": "#A9A3BA",
	"eternatus-eternamax": "#433C43",
	"eternatus": "#403D57",
	"excadrill": "#8B716E",
	"exeggcute": "#DA9283",
	"exeggutor-alola": "#445046",
	"exeggutor": "#445147",
	"exploud": "#917F95",
	"falinks": "#342E2D",
	"farfetchd-galar": "#827766",
	"farfetchd": "#BAA661",
	"farigiraf": "#26211D",
	"fearow": "#A06D3A",
	"feebas": "#CAAA6F",
	"fennekin": "#B15D33",
	"feraligatr": "#53A1BE",
	"ferroseed": "#717F71",
	"ferrothorn": "#405548",
	"fezandipiti": "#604045",
	"fidough": "#C9B166",
	"finizen": "#50C2D7",
	"finneon": "#55626E",
	"flaaffy": "#C798A0",
	"flabebe-blue": "#1E231A",
	"flabebe-orange": "#E89E19",
	"flabebe": "#DB783D",
	"flabebe-white": "#DFDCDA",
	"flabebe-yellow": "#E5D02C",
	"flamigo": "#644248",
	"flapple-gmax": "#6F4336",
	"flapple": "#68412E",
	"flareon": "#F8EA9E",
	"fletchinder": "#655B55",
	"fletchling": "#4E4645",
	"flittle": "#F3E5A1",
	"floatzel": "#6C5B46",
	"floette-blue": "#1D2B23",
	"floette-eternal": "#23191B",
	"floette-orange": "#DF9417",
	"floette": "#23291E",
	"floette-white": "#E3E4E1",
	"floette-yellow": "#5D714B",
	"floragato": "#476439",
	"florges-blue": "#40756D",
	"florges-orange": "#487963",
	"florges": "#497168",
	"florges-white": "#427462",
	"florges-yellow": "#4E7C60",
	"flutter-mane": "#2E3D44",
	"flygon": "#5F6B4E",
	"fomantis": "#52574E",
	"foongus": "#A3685A",
	"forretress": "#DABDE5",
	"fraxure": "#74A46E",
	"frigibax": "#9A9569",
	"frillish": "#C3E4F8",
	"froakie": "#475857",
	"frogadier": "#3B4D68",
	"froslass": "#685861",
	"frosmoth": "#A5AAC0",
	"fuecoco": "#9B4C35",
	"furfrou-dandy": "#83B661",
	"furfrou-debutante": "#E5E1A4",
	"furfrou-diamond": "#262321",
	"furfrou-heart": "#48403F",
	"furfrou-kabuki": "#594540",
	"furfrou-la-reine": "#42504A",
	"furfrou-matron": "#564B58",
	"furfrou-pharaoh": "#444A5E",
	"furfrou": "#DCE3CB",
	"furfrou-star": "#445154",
	"furret": "#916F4E",
	"gabite": "#868ED1",
	"gallade-mega": "#575E55",
	"gallade": "#59856B",
	"galvantula": "#A19378",
	"garbodor-gmax": "#8F9272",
	"garbodor": "#67765A",
	"garchomp-mega": "#5777C0",
	"garchomp": "#5B649B",
	"gardevoir-mega": "#89A280",
	"gardevoir": "#82B79C",
	"garganacl": "#685F5D",
	"gastly": "#9276C2",
	"gastrodon-east": "#4E7651",
	"gastrodon": "#9D7C49",
	"genesect-burn": "#7D5896",
	"genesect-chill": "#7D5B9C",
	"genesect-douse": "#795897",
	"genesect-no-drive": "#AA80BC",
	"genesect": "#614874",
	"genesect-shock": "#7B599A",
	"gengar-gmax": "#943E87",
	"gengar-mega": "#7A60AA",
	"gengar": "#8C7EC5",
	"geodude-alola": "#4D4F52",
	"geodude": "#8A8365",
	"gholdengo": "#E5BA5A",
	"gible": "#6FA0B9",
	"gigalith": "#50516B",
	"gimmighoul": "#794F37",
	"gimmighoul-roaming": "#635850",
	"girafarig": "#785138",
	"giratina-origin": "#4B4643",
	"giratina": "#59534A",
	"glaceon": "#699CA5",
	"glalie-mega": "#454C4E",
	"glalie": "#535559",
	"glameow": "#9E969E",
	"glastrier": "#E4ECEF",
	"gligar": "#A16994",
	"glimmet": "#38456D",
	"glimmora": "#293D70",
	"gliscor": "#878BDA",
	"gloom": "#B16239",
	"gogoat": "#3F6947",
	"golbat": "#56617A",
	"goldeen": "#E3D9D4",
	"golduck": "#52687F",
	"golem-alola": "#404A57",
	"golem": "#897664",
	"golett": "#6B6651",
	"golisopod": "#585253",
	"golurk": "#6FACAB",
	"goodra-hisui": "#A8A3B4",
	"goodra": "#EADCF6",
	"goomy": "#C7ACE7",
	"gorebyss": "#F6A0C0",
	"gossifleur": "#BF5D32",
	"gothita": "#AE9AB2",
	"gothitelle": "#535453",
	"gothorita": "#5A5A5B",
	"gouging-fire": "#24272A",
	"gourgeist-large": "#D78A4E",
	"gourgeist": "#5F4940",
	"gourgeist-small": "#533C2C",
	"gourgeist-super": "#D8894F",
	"grafaiai": "#383A44",
	"granbull": "#D7A1D2",
	"grapploct": "#486DBE",
	"graveler-alola": "#45433F",
	"graveler": "#86806A",
	"great-tusk": "#494764",
	"greavard": "#131416",
	"greedent": "#90594D",
	"greninja-ash": "#445365",
	"greninja": "#3F5C91",
	"grimer-alola": "#576E4F",
	"grimer": "#BAA4D7",
	"grimmsnarl-gmax": "#675F91",
	"grimmsnarl": "#6D708F",
	"grookey": "#CAD07B",
	"grotle": "#4B5D3F",
	"groudon": "#604D4F",
	"groudon-primal": "#6B4953",
	"grovyle": "#3C6038",
	"growlithe-hisui": "#906059",
	"growlithe": "#E7BA77",
	"grubbin": "#635245",
	"grumpig": "#74686E",
	"gulpin": "#98CA81",
	"gumshoos": "#877449",
	"gurdurr": "#C67071",
	"guzzlord": "#474B4F",
	"gyarados-mega": "#615A59",
	"gyarados": "#536065",
	"hakamo-o": "#726C56",
	"happiny": "#F8D0C7",
	"hariyama": "#635358",
	"hatenna": "#CBD4E4",
	"hatterene-gmax": "#959CB3",
	"hatterene": "#D2D5E3",
	"hattrem": "#CFD8E7",
	"haunter": "#9477C4",
	"hawlucha": "#C17350",
	"haxorus": "#5E5242",
	"heatmor": "#6A584D",
	"heatran": "#5D4F45",
	"heliolisk": "#565246",
	"helioptile": "#8B845C",
	"heracross-mega": "#4E78C2",
	"heracross": "#3C5E7C",
	"herdier": "#986642",
	"hippopotas": "#DFCE8B",
	"hippowdon": "#5B5A4C",
	"hitmonchan": "#C3A7A0",
	"hitmonlee": "#C4AA91",
	"hitmontop": "#57534E",
	"honchkrow": "#446A88",
	"honedge": "#525758",
	"ho-oh": "#6E5A45",
	"hoopa": "#5D5048",
	"hoopa-unbound": "#5C4B4C",
	"hoothoot": "#55463F",
	"hoppip": "#ED7C9D",
	"horsea": "#71C2F4",
	"houndoom-mega": "#4B4343",
	"houndoom": "#8D7D70",
	"houndour": "#89776B",
	"houndstone": "#D4D5DB",
	"huntail": "#78A9D2",
	"hydrapple": "#322924",
	"hydreigon": "#514B50",
	"hypno": "#E6D148",
	"igglybuff": "#F7D7EE",
	"illumise": "#A3ADDB",
	"impidimp": "#E786B1",
	"incineroar": "#724F4E",
	"indeedee": "#534F6A",
	"infernape": "#271D1B",
	"inkay": "#EC9C6B",
	"inteleon-gmax": "#4E545D",
	"inteleon": "#4F5558",
	"iron-boulder": "#2F2C29",
	"iron-bundle": "#8A4746",
	"iron-crown": "#417A81",
	"iron-hands": "#4E5153",
	"iron-jugulis": "#151315",
	"iron-leaves": "#4E7950",
	"iron-moth": "#564438",
	"iron-thorns": "#5F9D49",
	"iron-treads": "#1A1819",
	"iron-valiant": "#252323",
	"ivysaur": "#40654F",
	"jangmo-o": "#E4D698",
	"jellicent": "#BBE5F4",
	"jigglypuff": "#EBB1A9",
	"jirachi": "#E4DD82",
	"jolteon": "#EDE379",
	"joltik": "#F2DC4F",
	"jumpluff": "#EDE29B",
	"jynx": "#A96361",
	"kabuto": "#AF754E",
	"kabutops": "#BB924B",
	"kadabra": "#60563D",
	"kakuna": "#B0942E",
	"kangaskhan-mega": "#947666",
	"kangaskhan": "#6D5C56",
	"karrablast": "#485764",
	"kartana": "#BD9F65",
	"kecleon": "#788A4A",
	"keldeo": "#242324",
	"keldeo-resolute": "#EA7E54",
	"kilowattrel": "#675D57",
	"kingambit": "#4B3731",
	"kingdra": "#5694BE",
	"kingler-gmax": "#DF9060",
	"kingler": "#EB9658",
	"kirlia": "#80C271",
	"klang": "#B7C0C0",
	"klawf": "#743F33",
	"kleavor-noble": "#BFBB2D",
	"kleavor": "#4F5055",
	"klefki": "#665F5D",
	"klinklang": "#9C9C9B",
	"klink": "#CFD6D6",
	"koffing": "#D7D279",
	"komala": "#605546",
	"kommo-o": "#645C49",
	"koraidon-mount": "#261E1E",
	"koraidon": "#261E1E",
	"krabby": "#CE7B5B",
	"kricketot": "#93775F",
	"kricketune": "#815E4E",
	"krokorok": "#947A62",
	"krookodile": "#5E4B4F",
	"kubfu": "#575652",
	"kyogre": "#745368",
	"kyogre-primal": "#578AC6",
	"kyurem-black": "#565753",
	"kyurem": "#959E96",
	"kyurem-white": "#A5AA9F",
	"lairon": "#D4D9DA",
	"lampent": "#67676C",
	"landorus": "#6D5750",
	"landorus-therian": "#6B524E",
	"lanturn": "#88A6EE",
	"lapras-gmax": "#647A81",
	"lapras": "#5B7384",
	"larvesta": "#F4F3F2",
	"larvitar": "#A6E173",
	"latias-mega": "#9187BA",
	"latias": "#C7725D",
	"latios-mega": "#9186BA",
	"latios": "#548BB8",
	"leafeon": "#606244",
	"leavanny": "#5C7B2A",
	"lechonk": "#5B4F50",
	"ledian": "#62494D",
	"ledyba": "#695246",
	"lickilicky": "#F59AA3",
	"lickitung": "#C26969",
	"liepard": "#AE7096",
	"lileep": "#8C718B",
	"lilligant-hisui-noble": "#C6C92A",
	"lilligant-hisui": "#586946",
	"lilligant": "#B5AB4A",
	"lillipup": "#BE875E",
	"linoone-galar": "#5A5658",
	"linoone": "#ECDDE4",
	"litleo": "#614D48",
	"litten": "#4B4D68",
	"litwick": "#F5F5F7",
	"lokix": "#282727",
	"lombre": "#566544",
	"lopunny-mega": "#A67C5A",
	"lopunny": "#AE8963",
	"lotad": "#4F7F68",
	"loudred": "#ADA6E5",
	"lucario-mega": "#524644",
	"lucario": "#575C5F",
	"ludicolo": "#9CA86A",
	"lugia": "#F3F2F5",
	"lugia-shadow": "#555684",
	"lumineon": "#5F727F",
	"lunala": "#57505A",
	"lunatone": "#D1BD63",
	"lurantis": "#EDADB8",
	"luvdisc": "#EF7C89",
	"luxio": "#555856",
	"luxray": "#555652",
	"lycanroc-dusk": "#605548",
	"lycanroc-midnight": "#B5B8B5",
	"lycanroc": "#AFA399",
	"mabosstiff": "#373535",
	"machamp-gmax": "#635E5A",
	"machamp": "#808886",
	"machoke": "#8C828E",
	"machop": "#A8BDB0",
	"magby": "#D56462",
	"magcargo": "#BE5C3A",
	"magearna-original": "#6A4A3E",
	"magearna": "#AA9B91",
	"magikarp": "#D7874E",
	"magmar": "#A15D47",
	"magmortar": "#DC694C",
	"magnemite": "#484747",
	"magneton": "#87929E",
	"magnezone": "#CCD2D8",
	"makuhita": "#EEDB69",
	"malamar": "#937EB3",
	"mamoswine": "#A27E63",
	"manaphy": "#6CB6E7",
	"mandibuzz": "#554B44",
	"manectric-mega": "#E5D656",
	"manectric": "#E0D97B",
	"mankey": "#8C7049",
	"mantine": "#5A80B0",
	"mantyke": "#5A8BD5",
	"maractus": "#5A6E53",
	"mareanie": "#9C94B1",
	"mareep": "#D5B75F",
	"marill": "#75B3E4",
	"marowak-alola": "#5A5656",
	"marowak": "#7C6B5B",
	"marshadow-gen7": "#667078",
	"marshadow": "#667078",
	"marshtomp": "#80655F",
	"maschiff": "#6A3F30",
	"masquerain": "#C8DFE7",
	"maushold-family-of-four": "#F3F2F4",
	"maushold": "#F4F5F6",
	"mawile-mega": "#7A757C",
	"mawile": "#80756E",
	"medicham-mega": "#977E73",
	"medicham": "#E37E7D",
	"meditite": "#C9C9CA",
	"meganium": "#B2DF79",
	"melmetal-gmax": "#9E9B97",
	"melmetal": "#525152",
	"meloetta-pirouette": "#625754",
	"meloetta": "#9CCB9A",
	"meltan": "#E4CF87",
	"meowscarada": "#335231",
	"meowstic": "#5D7FAD",
	"meowth-alola": "#918E7B",
	"meowth-galar": "#BDAC9D",
	"meowth-gmax": "#F8EBB0",
	"meowth": "#957C46",
	"mesprit": "#605A68",
	"metagross-mega": "#556566",
	"metagross": "#465C6F",
	"metang": "#7097D9",
	"metapod": "#97C251",
	"mew": "#F0B0BA",
	"mewtwo-mega-x": "#9B7F9E",
	"mewtwo-mega-y": "#957B97",
	"mewtwo": "#DDD5E1",
	"mienfoo": "#EFE572",
	"mienshao": "#A093A6",
	"mightyena": "#7D7979",
	"milcery": "#F1ECD3",
	"milotic": "#615362",
	"miltank": "#584F4F",
	"mime-jr": "#6071E5",
	"mimikyu": "#CDC18F",
	"minccino": "#D2D0D1",
	"minior-blue-gen7": "#77C1EA",
	"minior-blue": "#77C1EA",
	"minior-green-gen7": "#8CCC56",
	"minior-green": "#8CCC56",
	"minior-indigo-gen7": "#5992CC",
	"minior-indigo": "#5992CC",
	"minior-orange-gen7": "#ECA35A",
	"minior-orange": "#ECA35A",
	"minior": "#87655B",
	"minior-red-gen7": "#DB7095",
	"minior-red": "#DB7095",
	"minior-violet-gen7": "#9887D1",
	"minior-violet": "#9887D1",
	"minior-yellow-gen7": "#E8D24A",
	"minior-yellow": "#E8D24A",
	"minun": "#E4DF6B",
	"miraidon-mount": "#1C1C26",
	"miraidon": "#1C1C26",
	"misdreavus": "#598AAC",
	"mismagius": "#A170A1",
	"moltres-galar": "#5A5758",
	"moltres": "#EEA150",
	"monferno": "#E6AB60",
	"morelull": "#F1DDDC",
	"morgrem": "#523F4F",
	"morpeko-hangry": "#735C76",
	"morpeko": "#736757",
	"mothim": "#7F6A50",
	"mr-mime-galar": "#4B6278",
	"mr-mime": "#4F5874",
	"mr-rime": "#616386",
	"mudbray": "#A66E59",
	"mudkip": "#8CCCEE",
	"mudsdale": "#5F6369",
	"muk-alola": "#74889D",
	"muk": "#AD94D0",
	"munchlax": "#5D8CA2",
	"munkidori": "#3C3A40",
	"munna": "#FCBDD0",
	"murkrow": "#515F8C",
	"musharna": "#F396A8",
	"nacli": "#AF8B7B",
	"naclstack": "#64483D",
	"naganadel": "#8C5E9B",
	"natu": "#656E2B",
	"necrozma-dawn": "#504F4E",
	"necrozma-dusk": "#524F47",
	"necrozma": "#5A5959",
	"necrozma-ultra": "#C9B776",
	"nickit": "#4E423F",
	"nidoking": "#896E97",
	"nidoqueen": "#636D78",
	"nidoran-f": "#7B8AB5",
	"nidoran-m": "#B27EA2",
	"nidorina": "#6C908F",
	"nidorino": "#B580A5",
	"nihilego": "#8DADD0",
	"nincada": "#A0A594",
	"ninetales-alola": "#BBDDF2",
	"ninetales": "#C1AC77",
	"ninjask": "#5C524C",
	"noctowl": "#584943",
	"noibat": "#967AB1",
	"noivern": "#574A4E",
	"nosepass": "#7778A1",
	"numel": "#C2C05C",
	"nuzleaf": "#AA8C6F",
	"nymble": "#7B8790",
	"obstagoon": "#504D50",
	"octillery": "#C13E3D",
	"oddish": "#425740",
	"ogerpon-cornerstone-mask": "#364133",
	"ogerpon-hearthflame-mask": "#43482F",
	"ogerpon-teal-mask": "#2B502D",
	"ogerpon-wellspring-mask": "#192C28",
	"oinkologne-f": "#5C3E3E",
	"oinkologne": "#4C4858",
	"okidogi": "#3C3937",
	"omanyte": "#E7DBA1",
	"omastar": "#5A6962",
	"onix": "#767776",
	"oranguru": "#6F7472",
	"orbeetle-gmax": "#6D4F53",
	"orbeetle": "#564850",
	"oricorio-pau": "#DFB5AF",
	"oricorio": "#5E444D",
	"oricorio-pom-pom": "#EFE390",
	"oricorio-sensu": "#9EA4D4",
	"orthworm": "#724D4F",
	"oshawott": "#ECEFE8",
	"overqwil": "#645E60",
	"pachirisu": "#EFF3F1",
	"palafin-hero": "#4783B1",
	"palafin": "#50C3D8",
	"palkia-origin": "#A69098",
	"palkia": "#605559",
	"palossand": "#F8C183",
	"palpitoad": "#545B64",
	"pancham": "#434840",
	"pangoro": "#505254",
	"panpour": "#7CBAEC",
	"pansage": "#41C05C",
	"pansear": "#E5624D",
	"parasect": "#EC935E",
	"paras": "#D18143",
	"passimian": "#585D4F",
	"patrat": "#C38C52",
	"pawmi": "#855632",
	"pawmo": "#ECB35C",
	"pawmot": "#D99819",
	"pawniard": "#5F5454",
	"pecharunt": "#CF599F",
	"pelipper": "#F3DD48",
	"perrserker": "#585453",
	"persian-alola": "#838895",
	"persian": "#F7EDB5",
	"petilil": "#90C051",
	"phanpy": "#88C7E8",
	"phantump": "#4B4B3E",
	"pheromosa": "#E4E2DC",
	"phione": "#69B3EC",
	"pichu": "#15130F",
	"pichu-spiky-eared": "#F0E569",
	"pidgeot-mega": "#B35359",
	"pidgeot": "#CC7951",
	"pidgeotto": "#BD6C40",
	"pidgey": "#BA8646",
	"pidove": "#B9ACA4",
	"pignite": "#E69A44",
	"pikachu-alola-cap": "#DFA642",
	"pikachu-belle": "#292822",
	"pikachu-cosplay": "#F2D233",
	"pikachu-gmax": "#EDD742",
	"pikachu-hoenn-cap": "#B0764C",
	"pikachu-kalos-cap": "#E2AE37",
	"pikachu-libre": "#D2A946",
	"pikachu-original-cap": "#E1C131",
	"pikachu-partner-cap": "#E2C130",
	"pikachu-phd": "#5D5846",
	"pikachu": "#E3C031",
	"pikachu-pop-star": "#D876A0",
	"pikachu-rock-star": "#734B37",
	"pikachu-sinnoh-cap": "#E7C631",
	"pikachu-starter": "#DBB52E",
	"pikachu-unova-cap": "#E0B036",
	"pikachu-world-cap": "#C67B3B",
	"pikipek": "#565151",
	"piloswine": "#F2AF81",
	"pincurchin": "#514756",
	"pineco": "#42615C",
	"pinsir-mega": "#71614F",
	"pinsir": "#98887D",
	"piplup": "#599CE8",
	"plusle": "#F1E871",
	"poipole": "#5A4768",
	"politoed": "#85C438",
	"poliwag": "#778CBB",
	"poliwhirl": "#7996C6",
	"poliwrath": "#557092",
	"poltchageist": "#323631",
	"polteageist": "#615354",
	"ponyta-galar": "#E2D9EC",
	"ponyta": "#DE9B40",
	"poochyena": "#5D5959",
	"popplio": "#6089D0",
	"porygon2": "#D95D7A",
	"porygon": "#62AAE1",
	"porygon-z": "#DC7262",
	"primarina": "#CFD5E4",
	"primeape": "#E5CC94",
	"prinplup": "#4975A5",
	"probopass": "#D05552",
	"psyduck": "#DDC668",
	"pumpkaboo-large": "#7B5738",
	"pumpkaboo": "#7A5738",
	"pumpkaboo-small": "#7B5837",
	"pumpkaboo-super": "#7A5636",
	"pupitar": "#B3B9DE",
	"purrloin": "#8969AC",
	"purugly": "#9190AF",
	"pyroar": "#775241",
	"pyukumuku": "#534949",
	"quagsire": "#7DD3FB",
	"quaquaval": "#3154B1",
	"quaxly": "#D7DBCC",
	"quaxwell": "#20232D",
	"quilava": "#1F120C",
	"quilladin": "#69683F",
	"qwilfish-hisui": "#625E5F",
	"qwilfish": "#55A39B",
	"raboot": "#604F43",
	"rabsca": "#B8328E",
	"raging-bolt": "#6E6E86",
	"raichu-alola": "#E8CA5C",
	"raichu": "#D8AA46",
	"raikou": "#746769",
	"ralts": "#7DB770",
	"rampardos": "#595B61",
	"rapidash-galar": "#A3A1CA",
	"rapidash": "#F2E697",
	"raticate-alola": "#54504D",
	"raticate": "#B18E53",
	"rattata-alola": "#6C6B6A",
	"rattata": "#AB93B6",
	"rayquaza-mega": "#5F7658",
	"rayquaza": "#4B5D46",
	"regice": "#6287BC",
	"regidrago": "#3B4C48",
	"regieleki": "#EEED64",
	"regigigas": "#5A6653",
	"regirock": "#BB8466",
	"registeel": "#898686",
	"relicanth": "#6F6154",
	"rellor": "#936F4C",
	"remoraid": "#B0DAEB",
	"reshiram": "#ADB0D5",
	"reuniclus": "#8EB693",
	"revavroom": "#494749",
	"rhydon": "#C6BFBD",
	"rhyhorn": "#727E85",
	"rhyperior": "#6B564E",
	"ribombee": "#F2F1F0",
	"rillaboom-gmax": "#446448",
	"rillaboom": "#415244",
	"riolu": "#424D5D",
	"roaring-moon": "#181822",
	"rockruff": "#595044",
	"roggenrola": "#5668A6",
	"rolycoly": "#4B4944",
	"rookidee": "#45464C",
	"roselia": "#609968",
	"roserade": "#57724F",
	"rotom-fan": "#66583B",
	"rotom-frost": "#E17140",
	"rotom-heat": "#EB6A4C",
	"rotom-mow": "#53583D",
	"rotom": "#76CEF6",
	"rotom-wash": "#E17242",
	"rowlet": "#CAA58D",
	"rufflet": "#ECE7C3",
	"runerigus": "#AB5464",
	"sableye-mega": "#D2375B",
	"sableye": "#796DA0",
	"salamence-mega": "#629DC0",
	"salamence": "#6AACB4",
	"salandit": "#443E3E",
	"salazzle": "#746679",
	"samurott-hisui": "#41486B",
	"samurott": "#516372",
	"sandaconda-gmax": "#584D44",
	"sandaconda": "#484137",
	"sandile": "#6F6153",
	"sandshrew-alola": "#DEEBEB",
	"sandshrew": "#A7953E",
	"sandslash-alola": "#608EAC",
	"sandslash": "#5E4A3A",
	"sandygast": "#DEDDAC",
	"sandy-shocks": "#494949",
	"sawk": "#404951",
	"sawsbuck-autumn": "#CB6452",
	"sawsbuck": "#A76E56",
	"sawsbuck-summer": "#C28D62",
	"sawsbuck-winter": "#AA8A78",
	"scatterbug": "#7C7974",
	"sceptile-mega": "#436443",
	"sceptile": "#6D8968",
	"scizor-mega": "#5B4A49",
	"scizor": "#74454A",
	"scolipede": "#7A525D",
	"scorbunny": "#C19C75",
	"scovillain": "#42483A",
	"scrafty": "#DA914D",
	"scraggy": "#E9AB32",
	"scream-tail": "#C29289",
	"scyther": "#4D6F54",
	"seadra": "#65B2ED",
	"seaking": "#D18979",
	"sealeo": "#56ABD8",
	"seedot": "#4A4740",
	"seel": "#E7EAF4",
	"seismitoad": "#4D5256",
	"sentret": "#CF9A89",
	"serperior": "#60A353",
	"servine": "#7BC14B",
	"seviper": "#565253",
	"sewaddle": "#689836",
	"sharpedo-mega": "#5077BA",
	"sharpedo": "#4F77A0",
	"shaymin": "#527342",
	"shaymin-sky": "#7D8250",
	"shedinja": "#A49054",
	"shelgon": "#ACABA5",
	"shellder": "#494855",
	"shellos-east": "#71BEE8",
	"shellos": "#DB8A83",
	"shelmet": "#8A878B",
	"shieldon": "#7C7970",
	"shiftry": "#756F5F",
	"shiinotic": "#BA7FBE",
	"shinx": "#7AB8EA",
	"shroodle": "#45495C",
	"shroomish": "#E6CF82",
	"shuckle": "#8C5140",
	"shuppet": "#7F89B7",
	"sigilyph": "#4D4F43",
	"silcoon": "#EDF1F3",
	"silicobra": "#585340",
	"silvally-bug": "#515354",
	"silvally-dark": "#505156",
	"silvally-dragon": "#4D5358",
	"silvally-electric": "#565756",
	"silvally-fairy": "#515056",
	"silvally-fighting": "#555454",
	"silvally-fire": "#7B4D46",
	"silvally-flying": "#55585F",
	"silvally-ghost": "#535058",
	"silvally-grass": "#3C6F59",
	"silvally-ground": "#635546",
	"silvally-ice": "#505158",
	"silvally": "#525257",
	"silvally-poison": "#514E5A",
	"silvally-psychic": "#524E57",
	"silvally-rock": "#525257",
	"silvally-steel": "#505258",
	"silvally-water": "#4D5157",
	"simipour": "#7DBAEA",
	"simisage": "#41B057",
	"simisear": "#E4674E",
	"sinistcha": "#393C32",
	"sinistea": "#7D678D",
	"sirfetchd": "#3D644B",
	"sizzlipede": "#683527",
	"skarmory": "#CED0E6",
	"skeledirge": "#784843",
	"skiddo": "#486733",
	"skiploom": "#B1DE43",
	"skitty": "#F2BC92",
	"skorupi": "#7E8BD7",
	"skrelp": "#A25A45",
	"skuntank": "#7D6D9D",
	"skwovet": "#827760",
	"slaking": "#B8988A",
	"slakoth": "#E5CEB0",
	"sliggoo-hisui": "#968BA5",
	"sliggoo": "#C5AEE9",
	"slither-wing": "#36262B",
	"slowbro-galar": "#A088A3",
	"slowbro-mega": "#A48F7F",
	"slowbro": "#F1C7CC",
	"slowking-galar": "#BFA2BF",
	"slowking": "#B99992",
	"slowpoke-galar": "#A8748B",
	"slowpoke": "#C7867B",
	"slugma": "#CA5E3D",
	"slurpuff": "#F8D7E2",
	"smeargle": "#EFEBBB",
	"smoliv": "#8D9748",
	"smoochum": "#EFE98C",
	"sneasel-hisui": "#8571A9",
	"sneasel": "#5D7D96",
	"sneasler": "#5A545E",
	"snivy": "#6DB145",
	"snom": "#F2F2F9",
	"snorlax-gmax": "#227067",
	"snorlax": "#40637E",
	"snorunt": "#504A44",
	"snover": "#F1F1F0",
	"snubbull": "#E08BA0",
	"sobble": "#AFD6EB",
	"solgaleo": "#332E28",
	"solosis": "#67A971",
	"solrock": "#ECB33B",
	"spearow": "#B76E3D",
	"spectrier": "#4A4654",
	"spewpa": "#645553",
	"spheal": "#83A4E5",
	"spidops": "#383829",
	"spinarak": "#6B6949",
	"spinda-blank": "#AC8A7E",
	"spinda-filled": "#955654",
	"spinda": "#B67770",
	"spiritomb": "#D19FBF",
	"spoink": "#D4BEBB",
	"sprigatito": "#99B374",
	"spritzee": "#E07990",
	"squawkabilly-blue": "#151B25",
	"squawkabilly-green": "#4E6642",
	"squawkabilly-white": "#5B5650",
	"squawkabilly-yellow": "#685D43",
	"squirtle": "#4A6F70",
	"stakataka": "#686C6D",
	"stantler": "#DDB588",
	"staraptor": "#574E46",
	"staravia": "#5A574F",
	"starly": "#57534C",
	"starmie": "#665356",
	"staryu": "#A57F51",
	"steelix-mega": "#708092",
	"steelix": "#9296AA",
	"steenee": "#AEB779",
	"stonjourner": "#847C73",
	"stoutland": "#6A6563",
	"stufful": "#6E564E",
	"stunfisk-galar": "#565453",
	"stunfisk": "#D8A569",
	"stunky": "#82719E",
	"sudowoodo": "#D39561",
	"suicune": "#7287A0",
	"sunflora": "#96A449",
	"sunkern": "#5F652D",
	"surskit": "#90BEE7",
	"swablu": "#84ADD2",
	"swadloon": "#99D940",
	"swalot": "#A78FCB",
	"swampert-mega": "#525B60",
	"swampert": "#5D6B7B",
	"swanna": "#F3F5F4",
	"swellow": "#6D69B4",
	"swinub": "#ECA375",
	"swirlix": "#F8F0F6",
	"swoobat": "#6A6C70",
	"sylveon": "#EBC3D1",
	"tadbulb": "#181716",
	"taillow": "#63609F",
	"talonflame": "#625547",
	"tandemaus": "#F4F5F6",
	"tangela": "#474A54",
	"tangrowth": "#4D4D5F",
	"tapu-bulu": "#584C3D",
	"tapu-fini": "#585658",
	"tapu-koko": "#ECBC5F",
	"tapu-lele": "#5E4F4B",
	"tarountula": "#D2D1CC",
	"tatsugiri-droopy": "#E54071",
	"tatsugiri": "#DF754B",
	"tatsugiri-stretchy": "#F5DF0C",
	"tauros-aqua-breed": "#3B3C3D",
	"tauros-blaze-breed": "#3F3C3C",
	"tauros-combat-breed": "#141313",
	"tauros": "#C69C6E",
	"teddiursa": "#DD9132",
	"tentacool": "#6BA0D8",
	"tentacruel": "#A06D6C",
	"tepig": "#6F553B",
	"terapagos": "#373D5E",
	"terapagos-stellar": "#2742A0",
	"terapagos-terastal": "#323A62",
	"terrakion": "#64544C",
	"thievul": "#564946",
	"throh": "#504742",
	"thundurus": "#535A62",
	"thundurus-therian": "#494E5B",
	"thwackey": "#5A5841",
	"timburr": "#6A554A",
	"ting-lu": "#3F4A44",
	"tinkatink": "#D85183",
	"tinkaton": "#916892",
	"tinkatuff": "#5D4162",
	"tirtouga": "#626A89",
	"toedscool": "#C9B964",
	"toedscruel": "#6D644A",
	"togedemaru": "#DEDDDB",
	"togekiss": "#DDF3E9",
	"togepi": "#E0E4CC",
	"togetic": "#F1F1F1",
	"torchic": "#F1A82F",
	"torkoal": "#6B584D",
	"tornadus": "#657059",
	"tornadus-therian": "#5A535A",
	"torracat": "#604B46",
	"torterra": "#48693D",
	"totodile": "#7DC5E6",
	"toucannon": "#545451",
	"toxapex": "#8A849D",
	"toxel": "#BA92DC",
	"toxicroak": "#708CD3",
	"toxtricity-gmax": "#EDC0BB",
	"toxtricity-low-key": "#786CB3",
	"toxtricity": "#5A4D51",
	"tranquill": "#5D5958",
	"trapinch": "#EA9177",
	"treecko": "#4D763A",
	"trevenant": "#565B4D",
	"tropius": "#56844F",
	"trubbish": "#7D9E67",
	"trumbeak": "#4A4C47",
	"tsareena": "#778A5A",
	"turtonator": "#744D4B",
	"turtwig": "#C3D46D",
	"tympole": "#CFC1A5",
	"tynamo": "#D5E5F2",
	"type-null": "#54504F",
	"typhlosion-hisui": "#E8D579",
	"typhlosion": "#EAD778",
	"tyranitar-mega": "#5C653A",
	"tyranitar": "#B2CB95",
	"tyrantrum": "#704042",
	"tyrogue": "#D5B8D5",
	"tyrunt": "#705855",
	"umbreon": "#646D73",
	"unfezant": "#5D5A57",
	"unown-b": "#1B1B1B",
	"unown-c": "#494949",
	"unown-d": "#1E1E1E",
	"unown-e": "#898989",
	"unown-exclamation": "#8F8F8F",
	"unown-f": "#4E4E4E",
	"unown-g": "#737373",
	"unown-h": "#737373",
	"unown-i": "#1F1F1F",
	"unown-j": "#4A4A4A",
	"unown-k": "#474747",
	"unown-l": "#4D4D4D",
	"unown-m": "#777777",
	"unown-n": "#1E1E1E",
	"unown-o": "#1D1D1D",
	"unown": "#424242",
	"unown-p": "#1E1E1E",
	"unown-q": "#848484",
	"unown-question": "#959595",
	"unown-r": "#1C1C1C",
	"unown-s": "#1C1C1C",
	"unown-t": "#444444",
	"unown-u": "#1B1B1B",
	"unown-v": "#707070",
	"unown-w": "#868686",
	"unown-x": "#212121",
	"unown-y": "#232323",
	"unown-z": "#4C4C4C",
	"ursaluna": "#60524C",
	"ursaluna-bloodmoon": "#9B7761",
	"ursaring": "#BE8958",
	"urshifu-gmax": "#61343C",
	"urshifu": "#515356",
	"urshifu-rapid-strike-gmax": "#42455C",
	"uxie": "#66655A",
	"vanillish": "#E8F5FB",
	"vanillite": "#E5F5FB",
	"vanilluxe": "#86AFD0",
	"vaporeon": "#587281",
	"varoom": "#414041",
	"veluza": "#5F495B",
	"venipede": "#54483F",
	"venomoth": "#D2C7D9",
	"venonat": "#8178C4",
	"venusaur-gmax": "#D16F66",
	"venusaur-mega": "#555652",
	"venusaur": "#70B8A2",
	"vespiquen": "#6E5B45",
	"vibrava": "#6D9B63",
	"victini": "#CF8053",
	"victreebel": "#78B76E",
	"vigoroth": "#E4E2E2",
	"vikavolt": "#506375",
	"vileplume": "#E5686D",
	"virizion": "#767F52",
	"vivillon-archipelago": "#4B413C",
	"vivillon-continental": "#937156",
	"vivillon-elegant": "#6C5B75",
	"vivillon-fancy": "#8E9E74",
	"vivillon-garden": "#405C45",
	"vivillon-high-plains": "#62554C",
	"vivillon-icy-snow": "#464646",
	"vivillon-jungle": "#47574B",
	"vivillon-marine": "#4E5461",
	"vivillon-modern": "#4F4847",
	"vivillon-monsoon": "#606164",
	"vivillon-ocean": "#4E4946",
	"vivillon": "#9D5B68",
	"vivillon-poke-ball": "#8C605A",
	"vivillon-polar": "#3D3F4B",
	"vivillon-river": "#565C59",
	"vivillon-sandstorm": "#635E53",
	"vivillon-savanna": "#546876",
	"vivillon-sun": "#CE875A",
	"vivillon-tundra": "#607C8F",
	"volbeat": "#5D4C47",
	"volcanion": "#794145",
	"volcarona": "#6D5851",
	"voltorb-hisui": "#D56C0F",
	"voltorb": "#CD6045",
	"vullaby": "#79635D",
	"vulpix-alola": "#F4F6F8",
	"vulpix": "#A8663F",
	"wailmer": "#5599C8",
	"wailord": "#56B4FA",
	"walking-wake": "#455568",
	"walrein": "#6D98C4",
	"wartortle": "#5C5A5C",
	"watchog": "#D08547",
	"wattrel": "#5D585A",
	"weavile": "#604655",
	"weedle": "#C7914D",
	"weepinbell": "#7FA85A",
	"weezing-galar": "#8F9684",
	"weezing": "#DAD191",
	"whimsicott": "#F5F4DB",
	"whirlipede": "#7A6C76",
	"whiscash": "#4F61A1",
	"whismur": "#DEB6D9",
	"wigglytuff": "#F6DEDE",
	"wiglett": "#9EA5A0",
	"wimpod": "#5C5363",
	"wingull": "#EFF3F5",
	"wishiwashi": "#535F7C",
	"wishiwashi-school": "#3C4D6E",
	"wobbuffet": "#77C5EC",
	"wo-chien": "#564F45",
	"woobat": "#6F6C78",
	"wooloo": "#F3EFEF",
	"wooper-paldea": "#664B49",
	"wooper": "#96B7E6",
	"wormadam": "#6B8561",
	"wormadam-sandy": "#625B4F",
	"wormadam-trash": "#8F6C6F",
	"wugtrio": "#5E4E53",
	"wurmple": "#E86767",
	"wynaut": "#6EC3EE",
	"wyrdeer": "#D8D7D7",
	"xatu": "#3D372F",
	"xerneas-active": "#585E6A",
	"xerneas": "#38424E",
	"xurkitree": "#524F47",
	"yamask-galar": "#51494B",
	"yamask": "#6C5951",
	"yamper": "#C4BA69",
	"yanma": "#604E3B",
	"yanmega": "#968250",
	"yungoos": "#977355",
	"yveltal": "#6D6161",
	"zacian-crowned": "#585B5C",
	"zacian": "#5B5155",
	"zamazenta-crowned": "#8B6B71",
	"zamazenta": "#554C6E",
	"zangoose": "#C09291",
	"zapdos-galar": "#4C463F",
	"zapdos": "#F1DD49",
	"zarude-dada": "#545552",
	"zarude": "#535652",
	"zebstrika": "#707471",
	"zekrom": "#454749",
	"zeraora": "#646645",
	"zigzagoon-galar": "#514F50",
	"zigzagoon": "#98846D",
	"zoroark-hisui": "#614B4D",
	"zoroark": "#57474D",
	"zorua-hisui": "#B28584",
	"zorua": "#63505B",
	"zubat": "#4C707C",
	"zweilous": "#716469",
	"zygarde-10": "#5A5E4D",
	"zygarde-complete": "#404442",
	"zygarde": "#70755E",
}
